@@ -258,8 +258,8 @@ int main(int argc, char *argv[])
         rawArgs << QString::fromLocal8Bit(argv[i]);
     }
 
-    KLocalizedString::setApplicationDomain("kdialog");
     QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kdialog");
 
     // enable high dpi support
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
@@ -276,10 +276,10 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Richard Moore"),QString(),"rich@kde.org");
     aboutData.addAuthor(i18n("Dawit Alemayehu"),QString(),"adawit@kde.org");
     aboutData.addAuthor(i18n("Kai Uwe Broulik"),QString(),"kde@privat.broulik.de");
+    KAboutData::setApplicationData(aboutData);
     QApplication::setWindowIcon(QIcon::fromTheme("system-run"));
 
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
@@ -301,6 +301,7 @@ int main(int argc, char *argv[])
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("msgbox"), i18n("Message Box dialog"), QLatin1String("text")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("inputbox"), i18n("Input Box dialog"), QLatin1String("text> <init")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("password"), i18n("Password dialog"), QLatin1String("text")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("newpassword"), i18n("New Password dialog"), QLatin1String("text")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("textbox"), i18n("Text Box dialog"), QLatin1String("file")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("textinputbox"), i18n("Text Input Box dialog"), QLatin1String("text> <init")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("combobox"), i18n("ComboBox dialog"), QLatin1String("text")));
@@ -504,6 +505,15 @@ int main(int argc, char *argv[])
       cout << qPrintable(result) << endl;
       return retcode ? 0 : 1;
     }
+    
+    // --newpassword text
+    if (parser.isSet("newpassword"))
+    {
+      QString result;
+      const bool retcode = Widgets::newPasswordBox(0, title, parser.value("newpassword"), result);
+      cout << qPrintable(result) << endl;
+      return retcode ? 0 : 1;
+    }
 
     // --passivepopup
     if (parser.isSet("passivepopup"))
